@@ -8,7 +8,8 @@ use warnings;
 
 use Time::HiRes 'time';
 
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
+our $Debug;
 
 sub new {
     my $class = shift;
@@ -146,7 +147,7 @@ sub _rotate {
         my ($orig, $rs, $period, $cs) = @$f;
         $i++;
         if ($i <= @$files-$self->{histories}) {
-            #$log->trace("Deleting old rotated file $dir/$orig$cs ...");
+            say "D: Deleting old rotated file $dir/$orig$cs ..." if $Debug;
             unlink "$dir/$orig$cs" or warn "Can't delete $dir/$orig$cs: $!";
             next;
         }
@@ -157,8 +158,7 @@ sub _rotate {
             $new .= ".1";
         }
         if ($new ne $orig) {
-            #$log->trace(
-            #    "Renaming rotated file $dir/$orig$cs -> $dir/$new$cs ...");
+            say "D: Renaming rotated file $dir/$orig$cs -> $dir/$new$cs ..." if $Debug;
             rename "$dir/$orig$cs", "$dir/$new$cs"
                 or warn "Can't rename '$dir/$orig$cs' -> '$dir/$new$cs': $!";
         }
@@ -168,6 +168,15 @@ sub _rotate {
     $self->_unlock if $locked;
 }
 
+sub _open {
+    my $self = shift;
+
+    my $fp = $self->file_path;
+    open $self->{_fh}, ">>", $fp or die "Can't open '$fp': $!";
+    my $oldfh = select $self->{_fh}; $| = 1; select $oldfh; # set autoflush
+    $self->{_fp} = $fp;
+}
+
 # (re)open file and optionally rotate if necessary
 sub _rotate_and_open {
     my ($self) = @_;
@@ -175,9 +184,10 @@ sub _rotate_and_open {
     my $fp = $self->file_path;
     my ($do_open, $do_rotate) = @_;
 
+    # stat the current file (not our handle _fp)
     my @st = stat($fp);
+    # file does not exist yet, create
     unless (-e _) {
-        # file does not exist yet, create
         $do_open++;
         goto DOIT;
     }
@@ -186,8 +196,7 @@ sub _rotate_and_open {
 
     # file is not opened yet, open
     unless ($self->{_fh}) {
-        $do_open++;
-        goto DOIT;
+        $self->_open;
     }
 
     # period has changed, rotate
@@ -203,6 +212,7 @@ sub _rotate_and_open {
         my $size  = $st[7];
         $inode    = $st[1];
         if ($size >= $self->{size}) {
+            say "D: Size of $self->{_fp} is $size, exceeds $self->{size}, rotating ..." if $Debug;
             $do_rotate++;
             $self->{_tmp_hack_give_suffix_to_fp} = 1;
             goto DOIT;
@@ -217,17 +227,8 @@ sub _rotate_and_open {
     }
 
   DOIT:
-    # rotate
-    if ($do_rotate) {
-        $self->_rotate;
-    }
-
-    # (re)open
-    if ($do_open || $do_rotate) {
-        open $self->{_fh}, ">>", $fp or die "Can't open '$fp': $!";
-        my $oldfh = select $self->{_fh}; $| = 1; select $oldfh; # set autoflush
-        $self->{_fp} = $fp;
-    }
+    $self->_rotate if $do_rotate;
+    $self->_open   if $do_rotate || $do_open; # (re)open
 }
 
 sub write {
@@ -307,7 +308,7 @@ File::Write::Rotate - Write to files that archive/rotate themselves
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
